==> maradns-1.0.18.tar.gz: maradns-1.0.18/tuzona/getzone_en.h <==
#define L_FATAL_COMMENT "# Fatal error: "
#define L_TIMEOUT "Connection timed out"
#define L_USAGE "Usage: getzone zone_name zone_server_IP"
#define L_VALID_IP "Please use a valid IP for the zone server"
#define L_NO_SOCK "Unable to create TCP socket"
#define L_NO_CONNECT "Unable to connect to zone server"
#define L_NO_SEND "Unable to create send string object"
#define L_NO_HEADER "Unable to make DNS header"
#define L_NO_ZSTRING "Unable to create zone string object"
#define L_QSTR2JS_ERROR "qstr2js"
#define L_APPEND_Z "Unable to append zone string to zone object"
#define L_APPEND_D "Unable to append dot at end of zone string object"
#define L_INVALID_NAME "Invalid form of zone name"
#define L_APPEND_ZS "Can not append zone string to send string"
#define L_ADD_QT "Could not add query type to send"
#define L_ADD_QC "Could not add query class to send"
#define L_SEND_2BYTE "Could not send 2-byte length header to zone server"
#define L_SEND_QUERY "Could not send query to zone server"
#define L_C_RRNAME "Could not create rr.name"
#define L_MNAME "Could not create soa.mname"
#define L_RNAME "Could not create soa.rname"
#define L_NOT_MANLY "Response from server is not long enough to hold header"
#define L_NO_GET "Could not allocate memory for get string"
#define L_NO_EXPAND "Could not allocate memory for expand string"
#define L_SERVER "Could not get packet from server"
#define L_DECOMPRESS "Fatal error performing decompression"
#define L_RHEADER "Could not read header from server"
#define L_FORMAT "Format error"
#define L_SERVER_FAIL "Server failure"
#define L_NAME "Name error"
#define L_NOTIMPL "Not implemented"
#define L_REFUSE "Refused"
#define L_RCODE "Rcode > 5"
#define L_DLABEL "Invalid dlabel in question"
#define L_READ_RR_H "Fatal error running read_rr_h"
#define L_GET_S "Can not make get string"
#define L_GET_COPY "Fatal error copying name to get"
#define L_BALIWICK "# Disabled out-of-bailiwick record follows"
#define L_HASH "# "
#define L_CGET "Can not make get string"
#define L_RDDATA "Problem getting rddata"
#define L_TRANS "Problem translating A record name"
#define LF "\n"
#define L_HNAME "Hname problem"
#define L_ZERO "No 0-length names!"

==> maradns_1.0.35.orig.tar.gz: maradns-1.0.35/tuzona/getzone_en.h <==
#define L_FATAL_COMMENT "# Fatal error: "
#define L_TIMEOUT "Connection timed out"
#define L_USAGE_GZ "Usage: getzone zone_name zone_server_IP"
#define L_VALID_IP "Please use a valid IP for the zone server"
#define L_NO_SOCK "Unable to create TCP socket"
#define L_NO_CONNECT "Unable to connect to zone server"
#define L_NO_SEND "Unable to create send string object"
#define L_NO_HEADER "Unable to make DNS header"
#define L_NO_ZSTRING "Unable to create zone string object"
#define L_QSTR2JS_ERROR "qstr2js"
#define L_APPEND_Z "Unable to append zone string to zone object"
#define L_APPEND_D "Unable to append dot at end of zone string object"
#define L_INVALID_NAME "Invalid form of zone name"
#define L_APPEND_ZS "Can not append zone string to send string"
#define L_ADD_QT "Could not add query type to send"
#define L_ADD_QC "Could not add query class to send"
#define L_SEND_2BYTE "Could not send 2-byte length header to zone server"
#define L_SEND_QUERY "Could not send query to zone server"
#define L_C_RRNAME "Could not create rr.name"
#define L_MNAME "Could not create soa.mname"
#define L_RNAME_GZ "Could not create soa.rname"
#define L_NOT_MANLY "Response from server is not long enough to hold header"
#define L_NO_GET "Could not allocate memory for get string"
#define L_NO_EXPAND "Could not allocate memory for expand string"
#define L_SERVER "Could not get packet from server"
#define L_DECOMPRESS "Fatal error performing decompression"
#define L_RHEADER "Could not read header from server"
#define L_FORMAT "Format error"
#define L_SERVER_FAIL "Server failure"
#define L_NAME "Name error"
#define L_NOTIMPL "Not implemented"
#define L_REFUSE "Refused"
#define L_RCODE "Rcode > 5"
#define L_DLABEL "Invalid dlabel in question"
#define L_READ_RR_H "Fatal error running read_rr_h"
#define L_GET_S "Can not make get string"
#define L_GET_COPY "Fatal error copying name to get"
#define L_BALIWICK "# Disabled out-of-bailiwick record follows"
#define L_HASH "# "
#define L_CGET "Can not make get string"
#define L_RDDATA "Problem getting rddata"
#define L_TRANS "Problem translating A record name"
#define LF "\n"
#define L_HNAME "Hname problem"
#define L_ZERO "No 0-length names!"
